Description Usage Arguments Value
This function plots the differences and 95% CIs from the reference dose in a forest plot. The function can draw a non-inferiority limit onto the figure at a value specified.
1 2 | plotDeltaFOM(dataframe, themethod, refdose = "Routine Dose",
nonilimit = -0.05, thetreatment = "Treatment")
|
dataframe |
This the dataframe that is the second list element returned by the prepareestimates function. The array is processed outside this function to allow for labeling and formatting the modalities before the plot is generated. |
themethod |
A character string that uses one of the following analysis methods: RRRC (random reader random case), FRRC (fixed reader, random case), RRFC (random reader, random case) |
refdose |
A text string specifying the name of the reference dose that should be printed on x-axis label |
nonilimit |
A numeric value to indicate where a dashed line should be drawn for a non-inferiority line to be drawn |
thetreatment |
A text string that indicates the name of the variable that pertains to the name of the modality. The JAFROC analysis will automatically use Treatment as this name. If for some reason the name is changed, this will allow that new name to be specified. |
ggplot2 figure object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.